(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/forms'), require('@angular/common')) :
    typeof define === 'function' && define.amd ? define('ng-generic-toggle', ['exports', '@angular/core', '@angular/forms', '@angular/common'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global['ng-generic-toggle'] = {}, global.ng.core, global.ng.forms, global.ng.common));
}(this, (function (exports, core, forms, common) { 'use strict';

    var CheckedStateDirective = /** @class */ (function () {
        function CheckedStateDirective(_templateRef) {
            this._templateRef = _templateRef;
            this._viewRef = this._templateRef.createEmbeddedView(null);
        }
        Object.defineProperty(CheckedStateDirective.prototype, "viewRef", {
            get: function () {
                return this._templateRef.createEmbeddedView(null);
            },
            enumerable: false,
            configurable: true
        });
        return CheckedStateDirective;
    }());
    CheckedStateDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[gtCheckedState]'
                },] }
    ];
    CheckedStateDirective.ctorParameters = function () { return [
        { type: core.TemplateRef }
    ]; };

    var UnCheckedStateDirective = /** @class */ (function () {
        function UnCheckedStateDirective(_templateRef) {
            this._templateRef = _templateRef;
            this._viewRef = this._templateRef.createEmbeddedView(null);
        }
        Object.defineProperty(UnCheckedStateDirective.prototype, "viewRef", {
            get: function () {
                return this._templateRef.createEmbeddedView(null);
            },
            enumerable: false,
            configurable: true
        });
        return UnCheckedStateDirective;
    }());
    UnCheckedStateDirective.decorators = [
        { type: core.Directive, args: [{
                    selector: '[gtUnCheckedState]'
                },] }
    ];
    UnCheckedStateDirective.ctorParameters = function () { return [
        { type: core.TemplateRef }
    ]; };

    var NgGenericToggleComponent = /** @class */ (function () {
        function NgGenericToggleComponent(_changeDetectorRef) {
            this._changeDetectorRef = _changeDetectorRef;
            this.isChecked = false;
            this.onChange = function (_) { };
            this.onTouched = function () { };
            this.isDisabled = false;
            this.uniqueId = "generic-toggle-" + ++NgGenericToggleComponent.nextUniqueId;
        }
        Object.defineProperty(NgGenericToggleComponent.prototype, "disabled", {
            get: function () {
                return this.isDisabled;
            },
            set: function (value) {
                this.isDisabled = value != null && "" + value !== 'false';
            },
            enumerable: false,
            configurable: true
        });
        NgGenericToggleComponent.prototype.ngAfterViewInit = function () {
            this.updateView();
            this._changeDetectorRef.detectChanges();
        };
        NgGenericToggleComponent.prototype.updateView = function () {
            this._viewContainerRef.detach();
            if (this.isChecked) {
                this._viewContainerRef.insert(this._checkedState.viewRef);
            }
            else {
                this._viewContainerRef.insert(this._unCheckedState.viewRef);
            }
            this._changeDetectorRef.markForCheck();
        };
        NgGenericToggleComponent.prototype.toggle = function () {
            if (this.disabled)
                return;
            this.isChecked = !this.isChecked;
            this.updateView();
            this.onChange(this.isChecked);
        };
        NgGenericToggleComponent.prototype.writeValue = function (obj) {
            this.isChecked = !!obj;
            if (!!this._unCheckedState.viewRef && !!this._checkedState.viewRef)
                this.updateView();
        };
        NgGenericToggleComponent.prototype.registerOnChange = function (fn) {
            this.onChange = fn;
        };
        NgGenericToggleComponent.prototype.registerOnTouched = function (fn) {
            this.onTouched = fn;
        };
        NgGenericToggleComponent.prototype.setDisabledState = function (isDisabled) {
            this.disabled = isDisabled;
            this._changeDetectorRef.markForCheck();
        };
        return NgGenericToggleComponent;
    }());
    NgGenericToggleComponent.nextUniqueId = 0;
    NgGenericToggleComponent.decorators = [
        { type: core.Component, args: [{
                    selector: 'ng-generic-toggle',
                    template: "<ng-container #vc></ng-container>",
                    providers: [
                        {
                            provide: forms.NG_VALUE_ACCESSOR,
                            useExisting: core.forwardRef(function () { return NgGenericToggleComponent; }),
                            multi: true
                        }
                    ],
                    changeDetection: core.ChangeDetectionStrategy.OnPush,
                    host: {
                        '[attr.tabindex]': 'disabled ? null : -1',
                        '(click)': 'toggle();',
                        '[id]': 'uniqueId',
                        '[class.generic-toggle-disabled]': 'disabled'
                    },
                    styles: [":host(.generic-toggle-disabled){opacity:.5}"]
                },] }
    ];
    NgGenericToggleComponent.ctorParameters = function () { return [
        { type: core.ChangeDetectorRef }
    ]; };
    NgGenericToggleComponent.propDecorators = {
        disabled: [{ type: core.Input, args: ['disabled',] }],
        uniqueId: [{ type: core.Input, args: ['id',] }],
        _checkedState: [{ type: core.ContentChild, args: [CheckedStateDirective, { static: true, read: CheckedStateDirective },] }],
        _unCheckedState: [{ type: core.ContentChild, args: [UnCheckedStateDirective, { static: true, read: UnCheckedStateDirective },] }],
        _viewContainerRef: [{ type: core.ViewChild, args: ['vc', { static: true, read: core.ViewContainerRef },] }]
    };

    var NgGenericToggleModule = /** @class */ (function () {
        function NgGenericToggleModule() {
        }
        return NgGenericToggleModule;
    }());
    NgGenericToggleModule.decorators = [
        { type: core.NgModule, args: [{
                    declarations: [
                        NgGenericToggleComponent,
                        CheckedStateDirective,
                        UnCheckedStateDirective
                    ],
                    imports: [
                        common.CommonModule
                    ],
                    exports: [
                        NgGenericToggleComponent,
                        CheckedStateDirective,
                        UnCheckedStateDirective
                    ]
                },] }
    ];

    /*
     * Public API Surface of ng-generic-toggle
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.CheckedStateDirective = CheckedStateDirective;
    exports.NgGenericToggleComponent = NgGenericToggleComponent;
    exports.NgGenericToggleModule = NgGenericToggleModule;
    exports.UnCheckedStateDirective = UnCheckedStateDirective;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=ng-generic-toggle.umd.js.map
