import { Directive, TemplateRef, Component, forwardRef, ChangeDetectionStrategy, ChangeDetectorRef, Input, ContentChild, ViewChild, ViewContainerRef, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { CommonModule } from '@angular/common';

class CheckedStateDirective {
    constructor(_templateRef) {
        this._templateRef = _templateRef;
        this._viewRef = this._templateRef.createEmbeddedView(null);
    }
    get viewRef() {
        return this._templateRef.createEmbeddedView(null);
    }
}
CheckedStateDirective.decorators = [
    { type: Directive, args: [{
                selector: '[gtCheckedState]'
            },] }
];
CheckedStateDirective.ctorParameters = () => [
    { type: TemplateRef }
];

class UnCheckedStateDirective {
    constructor(_templateRef) {
        this._templateRef = _templateRef;
        this._viewRef = this._templateRef.createEmbeddedView(null);
    }
    get viewRef() {
        return this._templateRef.createEmbeddedView(null);
    }
}
UnCheckedStateDirective.decorators = [
    { type: Directive, args: [{
                selector: '[gtUnCheckedState]'
            },] }
];
UnCheckedStateDirective.ctorParameters = () => [
    { type: TemplateRef }
];

class NgGenericToggleComponent {
    constructor(_changeDetectorRef) {
        this._changeDetectorRef = _changeDetectorRef;
        this.isChecked = false;
        this.onChange = (_) => { };
        this.onTouched = () => { };
        this.isDisabled = false;
        this.uniqueId = `generic-toggle-${++NgGenericToggleComponent.nextUniqueId}`;
    }
    get disabled() {
        return this.isDisabled;
    }
    set disabled(value) {
        this.isDisabled = value != null && `${value}` !== 'false';
    }
    ngAfterViewInit() {
        this.updateView();
        this._changeDetectorRef.detectChanges();
    }
    updateView() {
        this._viewContainerRef.detach();
        if (this.isChecked) {
            this._viewContainerRef.insert(this._checkedState.viewRef);
        }
        else {
            this._viewContainerRef.insert(this._unCheckedState.viewRef);
        }
        this._changeDetectorRef.markForCheck();
    }
    toggle() {
        if (this.disabled)
            return;
        this.isChecked = !this.isChecked;
        this.updateView();
        this.onChange(this.isChecked);
    }
    writeValue(obj) {
        this.isChecked = !!obj;
        if (!!this._unCheckedState.viewRef && !!this._checkedState.viewRef)
            this.updateView();
    }
    registerOnChange(fn) {
        this.onChange = fn;
    }
    registerOnTouched(fn) {
        this.onTouched = fn;
    }
    setDisabledState(isDisabled) {
        this.disabled = isDisabled;
        this._changeDetectorRef.markForCheck();
    }
}
NgGenericToggleComponent.nextUniqueId = 0;
NgGenericToggleComponent.decorators = [
    { type: Component, args: [{
                selector: 'ng-generic-toggle',
                template: "<ng-container #vc></ng-container>",
                providers: [
                    {
                        provide: NG_VALUE_ACCESSOR,
                        useExisting: forwardRef(() => NgGenericToggleComponent),
                        multi: true
                    }
                ],
                changeDetection: ChangeDetectionStrategy.OnPush,
                host: {
                    '[attr.tabindex]': 'disabled ? null : -1',
                    '(click)': 'toggle();',
                    '[id]': 'uniqueId',
                    '[class.generic-toggle-disabled]': 'disabled'
                },
                styles: [":host(.generic-toggle-disabled){opacity:.5}"]
            },] }
];
NgGenericToggleComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
NgGenericToggleComponent.propDecorators = {
    disabled: [{ type: Input, args: ['disabled',] }],
    uniqueId: [{ type: Input, args: ['id',] }],
    _checkedState: [{ type: ContentChild, args: [CheckedStateDirective, { static: true, read: CheckedStateDirective },] }],
    _unCheckedState: [{ type: ContentChild, args: [UnCheckedStateDirective, { static: true, read: UnCheckedStateDirective },] }],
    _viewContainerRef: [{ type: ViewChild, args: ['vc', { static: true, read: ViewContainerRef },] }]
};

class NgGenericToggleModule {
}
NgGenericToggleModule.decorators = [
    { type: NgModule, args: [{
                declarations: [
                    NgGenericToggleComponent,
                    CheckedStateDirective,
                    UnCheckedStateDirective
                ],
                imports: [
                    CommonModule
                ],
                exports: [
                    NgGenericToggleComponent,
                    CheckedStateDirective,
                    UnCheckedStateDirective
                ]
            },] }
];

/*
 * Public API Surface of ng-generic-toggle
 */

/**
 * Generated bundle index. Do not edit.
 */

export { CheckedStateDirective, NgGenericToggleComponent, NgGenericToggleModule, UnCheckedStateDirective };
//# sourceMappingURL=ng-generic-toggle.js.map
